
#line 2 "testpatternl.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

#define yywrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 54
#define YY_END_OF_BUFFER 55
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[297] =
    {   0,
        0,    0,   55,   54,   51,   53,   54,   52,   54,   54,
       48,   48,   31,   50,   50,   50,   50,   50,   50,   50,
       50,   50,   50,   50,   50,   50,   50,   50,   50,   50,
       50,   50,   50,   50,   51,    0,   50,   52,    0,   48,
       48,   50,    0,   48,   49,   50,   50,   48,   50,   50,
       50,   50,   50,   50,   50,   50,   50,   50,   50,   50,
       50,   18,   50,   50,   50,   50,   50,   19,   50,   50,
       50,   50,   50,   17,   50,   50,   50,   50,   50,   50,
       50,   50,   50,   50,   49,    0,   48,   49,    0,   50,
       49,   48,   50,   50,   36,   50,   50,   50,   50,   46,

       50,   50,   50,   50,   50,   50,   50,   50,   50,   50,
       50,   50,   50,   50,   50,   50,   50,   50,   50,   50,
       50,   50,   50,   50,   50,   50,   35,   50,   50,   50,
       50,   13,   50,   50,   50,   50,   49,   50,   50,   33,
       50,   47,   50,   50,   50,   50,   50,   38,   37,   28,
       50,   50,   50,   34,   14,   50,   50,   50,   50,   50,
       32,   50,   50,   50,   50,   50,   50,   50,   50,   50,
       50,   50,   50,   50,   50,   50,   47,   50,   50,   50,
       50,   50,   50,    1,   20,   26,   50,    2,   50,   50,
       50,   50,   50,   50,   50,   50,   50,   50,   50,   43,

       50,   50,    3,   21,   39,   50,   50,   50,   50,   50,
       50,   50,   50,   50,   50,   50,   50,   50,   50,   50,
       40,   50,   50,   50,   50,   50,   50,   50,   50,   47,
       50,   29,   50,   12,   50,   45,   50,   50,   47,   50,
       47,   41,   42,   50,   50,   24,    5,   50,   50,   50,
       50,   50,   50,   47,   27,   50,   50,   50,   50,   16,
       50,   50,   25,   22,   23,    4,   47,   30,    6,   15,
       44,   50,   50,   50,   50,   50,   50,   50,   50,   50,
       50,   50,   50,   50,   50,    7,   50,    8,   50,   50,
       50,   11,   10,   50,    9,    0

    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    5,    1,    1,    1,    6,    1,
        1,    1,    7,    1,    8,    9,    1,   10,   11,   11,
       11,   11,   11,   11,   11,   12,   12,    1,   13,    1,
        1,    1,    1,    1,   14,   15,   16,   17,   18,   19,
       20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
       30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
        1,    1,    1,    1,   40,    1,   41,   42,   43,   44,

       45,   46,   47,   48,   49,   50,   51,   52,   53,   54,
       55,   56,   30,   57,   58,   59,   60,   61,   62,   63,
       64,   65,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[66] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    3,    3,    3,
        3,    3,    1,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3
    } ;

static const flex_int16_t yy_base[301] =
    {   0,
        0,    0,  906,  947,  902,  947,  896,    0,  891,   56,
       60,   64,  947,  872,   68,   74,   70,   71,   75,   72,
       87,   76,   81,  119,  108,  109,  135,  130,  102,  143,
      122,  158,  133,  137,  875,  861,  947,    0,  852,  190,
      200,  844,  176,  204,  214,  229,  251,  246,  156,  164,
      182,  219,  233,  194,  234,  187,  148,  224,  264,  266,
      267,  275,  274,  271,  324,  294,  221,  833,  210,  278,
      292,  298,  312,  828,  295,  175,  303,  307,  334,  313,
      349,  351,  345,  355,  372,  384,  392,  401,  404,  411,
      415,    0,  390,  378,  314,  380,  409,  419,  420,  369,

      421,  344,  422,  431,  432,  425,  433,  434,  435,  438,
      436,  450,  441,  443,  447,  439,  449,  446,  473,  476,
      478,  480,  487,  484,  494,  497,  819,  499,  491,  501,
      504,  773,  503,  506,  507,  505,  512,  511,  518,  772,
      520,  752,  522,  538,  532,  537,  540,  750,  691,  665,
      541,  543,  558,  604,  590,  560,  561,  564,  547,  575,
      528,  578,  569,  567,  571,  586,  584,  585,  591,  587,
      589,  596,  602,  605,  600,  606,  612,  621,  616,  623,
      617,  629,  636,  463,  461,  459,  627,  453,  642,  637,
      646,  643,  656,  658,  651,  668,  661,  669,  666,  384,

      684,  631,  376,  365,  359,  685,  663,  689,  687,  697,
      664,  688,  692,  686,  714,  711,  712,  713,  715,  723,
      347,  720,  738,  736,  727,  735,  746,  741,  742,  335,
      739,  326,  748,  321,  743,  319,  763,  767,  315,  740,
      310,  302,  293,  756,  768,  280,  276,  769,  783,  776,
      779,  785,  799,  243,  242,  789,  800,  801,  803,  225,
      802,  814,  220,  186,  184,  174,  150,  147,  809,  144,
       98,  852,  817,  806,  827,  816,  826,  841,  823,  848,
      829,  832,  830,  855,  864,   94,  877,   92,  874,  878,
      866,   85,   82,  882,   78,  947,  937,  940,  943,   83

    } ;

static const flex_int16_t yy_def[301] =
    {   0,
      296,    1,  296,  296,  296,  296,  297,  298,  299,  296,
      300,  300,  296,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  296,  297,  296,  298,  299,  296,
      296,  300,  296,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  296,  296,  296,  296,  296,  300,
      300,   47,  300,  300,  300,  300,  300,  300,  300,  300,

      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  296,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,

      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,    0,  296,  296,  296,  296

    } ;

static const flex_int16_t yy_nxt[1013] =
    {   0,
        4,    5,    6,    7,    8,    9,   10,   10,    4,   11,
       12,   12,   13,   14,   15,   16,   17,   18,   14,   19,
       20,   21,   14,   22,   23,   24,   25,   26,   27,   14,
       28,   29,   30,   14,   31,   32,   33,   34,   14,   14,
       14,   15,   16,   17,   18,   14,   19,   20,   21,   14,
       22,   23,   24,   25,   26,   27,   28,   29,   30,   14,
       31,   32,   33,   34,   14,   40,   41,   41,   43,   44,
       44,   45,   43,   48,   48,   48,  296,   46,  296,  296,
      296,   46,  296,  296,  296,   42,  296,   54,   58,  296,
      296,   63,   49,  296,   50,  296,   47,   56,   64,   51,

      296,   52,  296,   60,   46,   59,  296,   57,   46,   55,
      296,   53,   61,   62,   54,   58,  296,  296,   63,   49,
       65,   50,   47,   78,   56,   64,   51,  296,   52,   60,
      296,   59,   66,   57,   79,   70,   67,   53,  296,   61,
       62,  296,   71,  296,   68,  296,   69,   75,   72,   76,
       78,  296,  296,   81,   84,  296,  296,   77,  296,   66,
       79,   83,   70,   67,  296,   73,  296,   74,   71,   93,
       80,   68,  296,   69,   75,   72,   76,   94,   82,   81,
      101,   84,  296,  296,   77,   88,   88,   88,   83,  127,
      296,   73,  296,   74,  296,  296,   93,   80,   43,   85,

       85,   85,  296,  100,   94,   82,  101,   86,   43,   87,
       87,   87,   43,   44,   44,   45,  127,   86,  296,   95,
       98,   46,   43,   45,   45,   45,  119,  296,  296,  296,
      100,   46,  296,  296,   86,   89,   90,  296,   91,   91,
       91,  296,  296,   96,   86,   95,   97,   98,   46,  102,
      296,  296,  118,  119,   43,   48,   48,   48,   46,  296,
       92,   92,   92,   46,   92,   92,   92,   92,   92,   92,
       96,   99,  296,   97,  296,  296,  102,  103,  118,  296,
      107,  104,  296,  296,  296,  105,  296,  106,  296,  110,
       46,   92,   92,   92,   92,   92,   92,   99,  108,  109,

      296,  296,  296,  296,  103,  111,  296,  107,  104,  120,
      296,  296,  105,  117,  106,  296,  110,  122,  296,  126,
      296,  296,  296,  296,  121,  108,  109,  296,  123,  296,
      124,  111,  296,  125,  296,  120,  128,  140,  112,  113,
      117,  132,  296,  296,  122,  129,  126,  130,  114,  115,
      121,  131,  296,  296,  123,  296,  124,  296,  135,  296,
      125,  116,  128,  296,  140,  112,  113,  296,  132,  147,
      133,  129,  134,  296,  130,  114,  115,  296,  131,  136,
       43,   85,   85,   85,  296,  135,  296,  116,  296,   86,
       89,   89,  296,  137,  137,  137,  147,  133,  296,  134,

       43,   87,   87,   87,  139,  138,  136,  141,  145,   86,
       88,   88,   88,  137,  137,  137,   86,  296,   86,  296,
       91,   91,   91,  296,   91,   91,   91,  296,  296,  296,
      296,  139,  138,  296,  141,  142,   86,  144,  146,  296,
      296,  296,  296,  296,  296,   86,  296,  296,  150,  296,
      143,  296,  152,  156,  296,  296,   84,  296,  296,  148,
       66,  296,  142,  151,  144,  146,  159,  296,  149,  296,
      155,  296,  154,  153,  157,  150,  143,  160,   53,  152,
      156,  296,  158,   84,  296,  148,  296,   66,  296,  151,
      161,  162,  296,  159,  149,  296,  155,  164,  154,  296,

      165,  157,  296,  160,   53,  296,  163,  296,  170,  296,
      168,  296,  296,  296,  296,  296,  166,  161,  162,  296,
      167,  137,  137,  137,  164,  169,  296,  165,  296,  176,
      296,  171,  172,  163,  177,  170,  296,  168,  174,  175,
      296,  173,  166,  180,  178,  296,  296,  167,  296,  296,
      179,  296,  169,  184,  182,  296,  176,  171,  185,  172,
      186,  177,  181,  183,  174,  175,  296,  173,  296,  296,
      180,  178,  296,  191,  189,  296,  179,  296,  190,  296,
      184,  182,  187,  296,  188,  185,  296,  186,  192,  181,
      183,  193,  296,  296,  296,  296,  196,  296,  296,  296,

      191,  189,  194,  197,  296,  190,  195,  200,  296,  187,
      296,  188,  296,  296,  296,  192,  198,  199,  193,  204,
      296,  202,  205,  196,  296,  296,  201,  203,  194,  296,
      197,  296,  206,  207,  200,  296,  208,  296,  209,  296,
      210,  212,  198,  199,  296,  296,  204,  202,  215,  205,
      296,  296,  214,  203,  296,  211,  213,  216,  206,  296,
      207,  217,  219,  208,  296,  209,  296,  210,  212,  296,
      228,  296,  296,  296,  296,  215,  296,  296,  218,  214,
      220,  211,  222,  213,  216,  223,  225,  226,  217,  219,
      221,  224,  296,  296,  296,  296,  296,  296,  230,  296,

      296,  234,  229,  237,  218,  296,  236,  220,  222,  227,
      231,  232,  223,  225,  226,  235,  221,  224,  233,  296,
      296,  296,  296,  296,  230,  240,  241,  234,  296,  229,
      237,  296,  242,  236,  239,  296,  227,  231,  232,  238,
      243,  244,  235,  296,  296,  233,  296,  296,  296,  296,
      296,  296,  240,  241,  296,  257,  296,  247,  296,  242,
      296,  239,  246,  250,  296,  252,  238,  243,  244,  248,
      245,  296,  251,  249,  253,  296,  296,  296,  254,  255,
      296,  296,  257,  247,  296,  259,  260,  296,  256,  246,
      250,  296,  252,  296,  258,  248,  245,  296,  251,  261,

      249,  253,  264,  262,  254,  263,  255,  296,  296,  296,
      296,  296,  259,  260,  296,  256,  265,  296,  268,  270,
      258,  266,  296,  267,  296,  296,  261,  296,  271,  264,
      262,  296,  263,  269,  296,  296,  296,  296,  296,  279,
      296,  296,  281,  265,  278,  268,  270,  266,  272,  296,
      267,  280,  296,  284,  288,  271,  296,   37,  282,  269,
      296,  286,  287,  296,   37,  279,  273,  274,  283,  281,
      275,  278,  296,  276,  296,  285,   35,  290,  280,  284,
      296,  288,  296,  277,  282,  296,  296,  286,  287,  289,
      296,  292,  294,  273,  274,  283,   37,  275,  291,   37,

      276,  295,  285,   35,  290,  296,  296,  296,  296,  277,
      293,  296,  296,  296,  296,  289,  296,  296,  292,  294,
      296,  296,  296,  296,  296,  291,  296,  296,  295,  296,
      296,  296,  296,  296,  296,  296,  293,   36,   36,   36,
       38,  296,   38,   39,   39,   39,    3,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,

      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296
    } ;

static const flex_int16_t yy_chk[1013] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,   10,   10,   10,   11,   11,
       11,   11,   12,   12,   12,   12,   15,   11,   17,   18,
       20,   12,   16,   19,   22,  300,  295,   17,   19,   23,
      293,   22,   15,  292,   16,   21,   11,   18,   23,   16,

      288,   16,  286,   20,   11,   19,  271,   18,   12,   17,
       29,   16,   21,   21,   17,   19,   25,   26,   22,   15,
       23,   16,   11,   29,   18,   23,   16,   24,   16,   20,
       31,   19,   24,   18,   29,   25,   24,   16,   28,   21,
       21,   33,   26,   27,   24,   34,   24,   28,   27,   28,
       29,   30,  270,   31,   34,  268,   57,   28,  267,   24,
       29,   33,   25,   24,   49,   27,   32,   27,   26,   49,
       30,   24,   50,   24,   28,   27,   28,   50,   32,   31,
       57,   34,  266,   76,   28,   43,   43,   43,   33,   76,
       51,   27,  265,   27,  264,   56,   49,   30,   40,   40,

       40,   40,   54,   56,   50,   32,   57,   40,   41,   41,
       41,   41,   44,   44,   44,   44,   76,   41,   69,   51,
       54,   44,   45,   45,   45,   45,   69,   52,  263,   67,
       56,   45,   58,  260,   40,   46,   46,   46,   46,   46,
       46,   53,   55,   52,   41,   51,   53,   54,   44,   58,
      255,  254,   67,   69,   48,   48,   48,   48,   45,   47,
       47,   47,   47,   48,   47,   47,   47,   47,   47,   47,
       52,   55,   59,   53,   60,   61,   58,   59,   67,   64,
       61,   59,   63,   62,  247,   59,   70,   60,  246,   64,
       48,   47,   47,   47,   47,   47,   47,   55,   62,   63,

       71,  243,   66,   75,   59,   64,   72,   61,   59,   70,
      242,   77,   59,   66,   60,   78,   64,   72,  241,   75,
       73,   80,   95,  239,   71,   62,   63,  236,   72,  234,
       72,   64,   65,   73,  232,   70,   77,   95,   65,   65,
       66,   80,   79,  230,   72,   78,   75,   79,   65,   65,
       71,   79,  102,   83,   72,  221,   72,   81,   83,   82,
       73,   65,   77,   84,   95,   65,   65,  205,   80,  102,
       81,   78,   82,  204,   79,   65,   65,  100,   79,   84,
       85,   85,   85,   85,  203,   83,   94,   65,   96,   85,
       86,   86,  200,   86,   86,   86,  102,   81,   93,   82,

       87,   87,   87,   87,   94,   93,   84,   96,  100,   87,
       88,   88,   88,   89,   89,   89,   85,   97,   88,   90,
       90,   90,   90,   91,   91,   91,   91,   98,   99,  101,
      103,   94,   93,  106,   96,   97,   87,   99,  101,  104,
      105,  107,  108,  109,  111,   88,  110,  116,  105,  113,
       98,  114,  107,  111,  118,  115,  116,  117,  112,  103,
      115,  188,   97,  106,   99,  101,  117,  186,  104,  185,
      110,  184,  109,  108,  112,  105,   98,  118,  113,  107,
      111,  119,  114,  116,  120,  103,  121,  115,  122,  106,
      119,  120,  124,  117,  104,  123,  110,  122,  109,  129,

      123,  112,  125,  118,  113,  126,  121,  128,  129,  130,
      126,  133,  131,  136,  134,  135,  124,  119,  120,  138,
      125,  137,  137,  137,  122,  128,  139,  123,  141,  136,
      143,  130,  131,  121,  138,  129,  161,  126,  134,  135,
      145,  133,  124,  143,  139,  146,  144,  125,  147,  151,
      141,  152,  128,  147,  145,  159,  136,  130,  151,  131,
      152,  138,  144,  146,  134,  135,  153,  133,  156,  157,
      143,  139,  158,  159,  157,  164,  141,  163,  158,  165,
      147,  145,  153,  160,  156,  151,  162,  152,  160,  144,
      146,  162,  167,  168,  166,  170,  165,  171,  155,  169,

      159,  157,  163,  166,  172,  158,  164,  169,  175,  153,
      173,  156,  154,  174,  176,  160,  167,  168,  162,  173,
      177,  171,  174,  165,  179,  181,  170,  172,  163,  178,
      166,  180,  175,  176,  169,  187,  177,  182,  178,  202,
      179,  181,  167,  168,  183,  190,  173,  171,  187,  174,
      189,  192,  183,  172,  191,  180,  182,  189,  175,  195,
      176,  190,  192,  177,  193,  178,  194,  179,  181,  197,
      202,  207,  211,  150,  199,  187,  196,  198,  191,  183,
      193,  180,  195,  182,  189,  196,  198,  199,  190,  192,
      194,  197,  201,  206,  214,  209,  212,  208,  207,  149,

      213,  211,  206,  214,  191,  210,  213,  193,  195,  201,
      208,  209,  196,  198,  199,  212,  194,  197,  210,  216,
      217,  218,  215,  219,  207,  217,  218,  211,  222,  206,
      214,  220,  219,  213,  216,  225,  201,  208,  209,  215,
      220,  222,  212,  226,  224,  210,  223,  231,  240,  228,
      229,  235,  217,  218,  227,  240,  233,  225,  148,  219,
      142,  216,  224,  228,  244,  231,  215,  220,  222,  226,
      223,  237,  229,  227,  233,  238,  245,  248,  235,  237,
      140,  132,  240,  225,  250,  245,  248,  251,  238,  224,
      228,  249,  231,  252,  244,  226,  223,  256,  229,  249,

      227,  233,  252,  250,  235,  251,  237,  253,  257,  258,
      261,  259,  245,  248,  274,  238,  253,  269,  258,  261,
      244,  256,  262,  257,  276,  273,  249,  127,  262,  252,
      250,  279,  251,  259,  277,  275,   74,  281,  283,  274,
      282,   68,  276,  253,  273,  258,  261,  256,  269,  278,
      257,  275,   42,  279,  283,  262,  280,   39,  277,  259,
      272,  281,  282,  284,   36,  274,  272,  272,  278,  276,
      272,  273,  285,  272,  291,  280,   35,  285,  275,  279,
       14,  283,  289,  272,  277,  287,  290,  281,  282,  284,
      294,  289,  291,  272,  272,  278,    9,  272,  287,    7,

      272,  294,  280,    5,  285,    3,    0,    0,    0,  272,
      290,    0,    0,    0,    0,  284,    0,    0,  289,  291,
        0,    0,    0,    0,    0,  287,    0,    0,  294,    0,
        0,    0,    0,    0,    0,    0,  290,  297,  297,  297,
      298,    0,  298,  299,  299,  299,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,

      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "testpatternl.l"
/*
 *
 *   Test pattern generator for Gimp-Print
 *
 *   Copyright 2001 Robert Krawitz <rlk@alum.mit.edu>
 *
 *   This program is free software; you can redistribute it and/or modify it
 *   under the terms of the GNU General Public License as published by the Free
 *   Software Foundation; either version 2 of the License, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful, but
 *   WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *   or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 *   for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
#line 22 "testpatternl.l"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include "testpattern.h"

#pragma GCC diagnostic ignored "-Wredundant-decls"
#pragma GCC diagnostic ignored "-Wunused-function"

#define YY_NO_UNPUT

int mylineno = 1;

extern YYSTYPE yylval;

static char *
c_strstrip(char *s)
{
  size_t len = strlen(s);
  if (len >= 2 && ((s[0] == '"' && s[len - 1] == '"') ||
		   (s[0] == '\'' && s[len - 1] == '\'')))
    {
      char *sn = malloc(len - 1);
      memcpy(sn, s + 1, len - 2);
      sn[len - 2] = '\0';
      return sn;
    }
  else
    return stp_strdup(s);
}

#define DBG(x)						\
do							\
  {							\
    if (getenv("STP_TESTPATTERN_DEBUG"))		\
      fprintf(stderr, "'%s' => %s\n", yytext, #x);	\
  }							\
 while (0)


#line 829 "testpatternl.c"
#line 830 "testpatternl.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 80 "testpatternl.l"


#line 1050 "testpatternl.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 297 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 947 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 82 "testpatternl.l"
DBG(GAMMA); return GAMMA;
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 83 "testpatternl.l"
DBG(LEVEL); return LEVEL;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 84 "testpatternl.l"
DBG(STEPS); return STEPS;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 85 "testpatternl.l"
DBG(INK_LIMIT); return INK_LIMIT;
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 86 "testpatternl.l"
DBG(PRINTER); return PRINTER;
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 87 "testpatternl.l"
DBG(PARAMETER); return PARAMETER;
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 88 "testpatternl.l"
DBG(PARAMETER_INT); return PARAMETER_INT;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 89 "testpatternl.l"
DBG(PARAMETER_BOOL); return PARAMETER_BOOL;
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 90 "testpatternl.l"
DBG(PARAMETER); return PARAMETER;
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 91 "testpatternl.l"
DBG(PARAMETER_FLOAT); return PARAMETER_FLOAT;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 92 "testpatternl.l"
DBG(PARAMETER_CURVE); return PARAMETER_CURVE;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 93 "testpatternl.l"
DBG(DENSITY); return DENSITY;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 94 "testpatternl.l"
DBG(TOP); return TOP;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 95 "testpatternl.l"
DBG(LEFT); return LEFT;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 96 "testpatternl.l"
DBG(SIZE_MODE); return SIZE_MODE;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 97 "testpatternl.l"
DBG(RELATIVE); return RELATIVE;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 98 "testpatternl.l"
DBG(PT); return PT;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 99 "testpatternl.l"
DBG(IN); return IN;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 100 "testpatternl.l"
DBG(MM); return MM;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 101 "testpatternl.l"
DBG(HSIZE); return HSIZE;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 102 "testpatternl.l"
DBG(VSIZE); return VSIZE;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 103 "testpatternl.l"
DBG(BLACKLINE); return BLACKLINE;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 104 "testpatternl.l"
DBG(COLORLINE); return COLORLINE;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 105 "testpatternl.l"
DBG(PATTERN); return PATTERN;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 106 "testpatternl.l"
DBG(XPATTERN); return XPATTERN;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 107 "testpatternl.l"
DBG(IMAGE); return IMAGE;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 108 "testpatternl.l"
DBG(EXTENDED); return EXTENDED;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 109 "testpatternl.l"
DBG(GRID); return GRID;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 110 "testpatternl.l"
DBG(CHANNEL); return CHANNEL;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 111 "testpatternl.l"
DBG(PAGESIZE); return PAGESIZE;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 112 "testpatternl.l"
DBG(SEMI); return SEMI;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 113 "testpatternl.l"
DBG(MODE); return MODE;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 114 "testpatternl.l"
yylval.ival = CMYK;DBG(CMYK); return CMYK;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 115 "testpatternl.l"
yylval.ival = CMYK;DBG(KCMY); return KCMY;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 116 "testpatternl.l"
yylval.ival = RGB;DBG(RGB); return RGB;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 117 "testpatternl.l"
yylval.ival = RGB;DBG(CMY); return CMY;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 118 "testpatternl.l"
yylval.ival = GRAY;DBG(GRAY); return GRAY;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 119 "testpatternl.l"
yylval.ival = GRAY;DBG(GRAY); return GRAY;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 120 "testpatternl.l"
yylval.ival = WHITE;DBG(WHITE); return WHITE;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 121 "testpatternl.l"
DBG(OUTPUT); return OUTPUT;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 122 "testpatternl.l"
DBG(MESSAGE); return MESSAGE;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 123 "testpatternl.l"
DBG(NOSCALE); return NOSCALE;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 124 "testpatternl.l"
DBG(ROUND); return ROUND;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 125 "testpatternl.l"
DBG(START_JOB); return START_JOB;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 126 "testpatternl.l"
DBG(END_JOB); return END_JOB;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 127 "testpatternl.l"
DBG(END); return END;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 129 "testpatternl.l"
yylval.sval = yytext;DBG(COLOR); return COLOR;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 130 "testpatternl.l"
yylval.ival = strtol(yytext, NULL, 0); yylval.dval = (double) yylval.ival; DBG(tINT); return tINT;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 131 "testpatternl.l"
yylval.dval = strtod(yytext, NULL); DBG(tDOUBLE); return tDOUBLE;
	YY_BREAK
case 50:
/* rule 50 can match eol */
YY_RULE_SETUP
#line 132 "testpatternl.l"
yylval.sval = c_strstrip(yytext); DBG(tSTRING); return tSTRING;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 133 "testpatternl.l"
DBG(whitespace); 	/* Skip blanks/tabs */
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 134 "testpatternl.l"
DBG(comment); 	/* Skip comments */
	YY_BREAK
case 53:
/* rule 53 can match eol */
YY_RULE_SETUP
#line 135 "testpatternl.l"
DBG(newline); mylineno++;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 136 "testpatternl.l"
ECHO;
	YY_BREAK
#line 1379 "testpatternl.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 297 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 297 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 296);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 136 "testpatternl.l"
